@@ -27,9 +27,12 @@
 
 #include <libbonobo.h>
 
+#include <glib/gi18n.h>
+
 #include <gmenu-tree.h>
 
 #include <libpanel-util/panel-glib.h>
+#include <libpanel-util/panel-show.h>
 
 #include "launcher.h"
 #include "panel.h"
@@ -849,7 +852,7 @@ panel_addto_dialog_response (GtkWidget *widget_dialog,
 	switch (response_id) {
 	case GTK_RESPONSE_HELP:
 		panel_show_help (gtk_window_get_screen (GTK_WINDOW (dialog->addto_dialog)),
-				 "user-guide.xml", "gospanel-15");
+				 "user-guide", "gospanel-15", NULL);
 		break;
 
 	case PANEL_ADDTO_RESPONSE_ADD:
